@@ -334,7 +334,7 @@ class LocalPorvider(BaseProvider):
         """  
             table_name: 'AShareDescription'
             input:instruments:List(str),fields:List(str)
-                  optional: stkcode = None,fields =None,by [ann_date,reports_period]
+                  optional: stkcode = None,fields =None
             output: DataFrame
             fields : listdate, delistdate, list_boardname
         """
@@ -344,7 +344,7 @@ class LocalPorvider(BaseProvider):
         """
             table_name: 'AShareST'
             input:instruments:List(str),fields:List(str)
-                  optional:stkcode = None,fields =None,by [ann_date,reports_period]
+                  optional:stkcode = None,fields =None
             output: DataFrame
             fields : suspend_date:str,resump_date:str
         """
@@ -354,11 +354,21 @@ class LocalPorvider(BaseProvider):
         """ 
             table_name: 'AShareTradingSuspension'
             input:instruments:List(str),fields:List(str)
-                  optional: stkcode = None,fields =None,by [ann_date,reports_period]
+                  optional: stkcode = None,fields =None
             output: DataFrame
             fields : suspend_date,resump_date           
         """
         return InstSP.ashare_suspension(stkcode,fields)
+    
+    def suntime_typedict(self,organid= None,fields =None):
+        """ 
+            table_name: 'AShareTradingSuspension'
+            input:instruments:List(str),fields:List(str)
+                  optional: stkcode = None,fields =None
+            output: DataFrame
+            fields : suspend_date,resump_date           
+        """
+        return InstSP.suntime_typedict(organid,fields)
 
     def Industrycompo_citics(self,stockcode = None,level = None):
         """  
@@ -499,6 +509,17 @@ class LocalPorvider(BaseProvider):
             fields : ...
         """
         return FRP.repo_holder_number(instruments,fields,**kws)
+    
+
+    def repo_inside_holder(self,instruments,fields = None,**kws):
+        """
+            table_name: 'AShareInsideHolder'
+            input:instruments:List(str),fields:List(str)
+                  optional: start_date:str,end_date:str,by [ann_date,reports_period]
+            output: DataFrame
+            fields : ...
+        """
+        return FRP.repo_inside_holder(instruments,fields,**kws)
 
     def repo_issuedate_pre(self,instruments,fields = None,**kws):
         """
@@ -575,6 +596,30 @@ class LocalPorvider(BaseProvider):
         """
         return CDP.stk_rating(instruments,fields,window_days,**kws)
         
+    def suntime_confc_stk(self,instruments,fields = None,**kws):
+        """
+            table_name: 'CON_FORECAST_STK'
+            input:instruments:List(str),fields:List(str)
+                  window_days: 30d,90d,180d
+                  optional: start_date:str,end_date:str,by [ann_date,reports_period]
+            output: DataFrame
+            fields : ...
+        """
+        return CDP.suntime_confc_stk(instruments,fields,**kws)
+
+    def suntime_repofc_stk(self,instruments,fields = None,**kws):
+        """
+            table_name: 'RPT_FORECAST_STK'
+            input:instruments:List(str),fields:List(str)
+                  window_days: 30d,90d,180d
+                  optional: start_date:str,end_date:str,by [ann_date,reports_period]
+            output: DataFrame
+            fields : ...
+        """
+        return CDP.suntime_repofc_stk(instruments,fields,**kws)
+
+
+
 
 TDP = getattr(daily,provider_config["TDP"])()
 IdxSP = getattr(status,provider_config["IdxSP"])()
