@@ -37,6 +37,9 @@ ashare_sktrating_30d = os.path.join(data_path,r"AShareStockRatingConsus_30D")
 ashare_sktrating_90d = os.path.join(data_path,r"AShareStockRatingConsus_90D")
 ashare_sktrating_180d = os.path.join(data_path,r"AShareStockRatingConsus_180D")
 
+suntime_confc_stk = os.path.join(data_path,r"CON_FORECAST_STK")
+suntime_repofc_stk = os.path.join(data_path,r"RPT_FORECAST_STK")
+
 class BaseConsusDataProvider(abc.ABC):
 
     @abc.abstractmethod
@@ -84,4 +87,12 @@ class LoacalConsusProvider(BaseConsusDataProvider):
     @print_func_time
     def stk_rating(self,instruments,fields,window_days,**kws):
         path = eval('_'.join(["ashare_sktrating",window_days]))
-        return self.get_repo_data(path,instruments,fields,tidx = ["rating_date"],**kws)
\ No newline at end of file
+        return self.get_repo_data(path,instruments,fields,tidx = ["rating_date"],**kws)
+    
+    @print_func_time
+    def suntime_confc_stk(self,instruments,fields,**kws):
+        return self.get_repo_data(suntime_confc_stk,instruments,fields,tidx = ["con_date"],**kws)
+
+    @print_func_time
+    def suntime_repofc_stk(self,instruments,fields,**kws):
+        return self.get_repo_data(suntime_repofc_stk,instruments,fields,tidx = ["create_date"],**kws)
\ No newline at end of file
